# This script will copy required files over
echo "Making sure zboard-config is closed..."
zboard-config stop
pkill -9 zboard-config
echo "Copying files..."
mkdir /usr/share/zboard-config
mkdir /usr/share/zboard-config/maps
cp ./src/zboard-config /usr/bin/
cp -r ./zboard-config /usr/share/
echo "Done! Type 'zboard-config --help' for a list of commands."
